@@ -20,8 +20,6 @@ import re
 class MarkdownConverter:
     def __init__(self, markdown_content):
         self.markdown_content = self.format_markdown(markdown_content)
-        # print(self.markdown_content)
-        
         FileUtils.create_paths(Config.BASE_PATH)
 
     def format_markdown(self, markdown_text):
@@ -63,29 +61,7 @@ class MarkdownConverter:
                 # 如果下一行是列表项，在当前行后添加空行
                 if re.match(r'^\s*(\d+\.|\-)', next_line):
                     line = line + '\n'
-            
-            # 特殊处理：对于以数字开头且后面是粗体的行，进行转义
-            # 避免被Markdown库误识别为有序列表项
-            # if re.match(r'^\s*\d+\.\s*\*\*', line):
-            #     # 转义数字点号，使其不被识别为列表项
-            #     line = re.sub(r'^(\s*)(\d+)\.(\s*\*\*)', r'\1\2\\.\3', line)
-                
-            #     # 确保转义后的行后面有适当的换行，避免HTML结构问题
-            #     if i + 1 < len(lines) and re.match(r'^\s*\-\s*\*\*', lines[i + 1]):
-            #         line = line + '\n\n'  # 添加两个换行，确保正确的HTML结构
-            
-            # 计算当前行的缩进级别
-            # line_stripped = line.lstrip()
-            # indent_count = len(line) - len(line_stripped)
-            # # print(f"line: {line}，indent_count: {indent_count}")
-            # if indent_count > 0 :
-            #     indent_count = indent_count * 2
-            # # 保持原有缩进级别，不要翻倍，避免过度缩进
-            #     tab_indent = ' ' * indent_count
-            #     a = tab_indent + line_stripped
-            #     processed_lines.append(a)
-            # else:
-            #     processed_lines.append(line)
+            processed_lines.append(line)
         return '\n'.join(processed_lines)
 
     def to_html(self):
@@ -276,7 +252,6 @@ class MarkdownConverter:
             # 计算当前行的缩进级别
             line_stripped = line.lstrip()
             indent_count = len(line) - len(line_stripped)
-            # print(f"line: {line}，indent_count: {indent_count}")
             if indent_count > 0 :
                 indent_count = indent_count * 2
             # 保持原有缩进级别，不要翻倍，避免过度缩进
@@ -286,10 +261,8 @@ class MarkdownConverter:
             else:
                 processed_lines.append(line)
         markdown_content = '\n'.join(processed_lines)
-
         # markdown 转换为 html
         html_content = markdown.markdown(markdown_content, extensions=['tables'])
-        # print(self.html_content)
         # 逐行处理HTML代码，在<ol>、<li>、<ul>标签前添加换行
         html_content = self._process_html_line_breaks(html_content)
         print('='*50)
@@ -428,10 +401,15 @@ class MarkdownConverter:
         :param style: 样式内容，需要设置body、H1-H6、table等的样式，用来控制
         :return: 文件名
         """
+        html_content = markdown.markdown(self.markdown_content, extensions=['tables'])
+        # 逐行处理HTML代码，在<ol>、<li>、<ul>标签前添加换行
+        html_content = self._process_html_line_breaks(html_content)
+        print('='*50)
+        print(html_content)
         if file_name is None or file_name=='':
             file_name = CommonUtils.generate_uuid()+ ".pdf";
         elif not file_name.endswith(".pdf"):
             file_name += ".pdf"
-        html_text =  style + self.html_content
+        html_text =  style + html_content
         HTML(string=html_text).write_pdf(Config.BASE_PATH+ file_name)
         return file_name
